@@ -8,7 +8,6 @@ import pickle
 import os
 import yaml
 
-
 def tokenize( sentences ):
         tokens_list = []
         vocabulary = []
@@ -40,7 +39,7 @@ def make_inference_models(encoder_inputs, encoder_states, decoder_embedding, dec
     
     return encoder_model , decoder_model
 
-def str_to_tokens( sentence : str ):
+def str_to_tokens( sentence : str , tokenizer, maxlen_questions):
     words = sentence.lower().split()
     tokens_list = list()
     for word in words:
@@ -137,11 +136,8 @@ def make_test_chatbot(dir_path, files_list, ntest):
 
     enc_model , dec_model = make_inference_models(encoder_inputs, encoder_states, decoder_embedding, decoder_inputs, decoder_lstm, decoder_dense)
 
-    tokenizer = preprocessing.text.Tokenizer()
-    tokenizer.fit_on_texts(questions+answers)
-
     for _ in range(ntest):
-        states_values = enc_model.predict(str_to_tokens( input( 'Enter question : ' ) ) )
+        states_values = enc_model.predict(str_to_tokens(input( 'Enter question : '), tokenizer, maxlen_questions))
         empty_target_seq = np.zeros( ( 1 , 1 ) )
         empty_target_seq[0, 0] = tokenizer.word_index['start']
         stop_condition = False
